powered by
sum for summarise_all aware of POSIX objects
.accumulated_posix_aware(variable, na.rm = FALSE)
the sum for any other variables, but the first for POSIXct variables
the variable as it is passed to the .fixed_metrics function
logical to pass to na.rm argument from sum
sapfluxnetr:::.accumulated_posix_aware(c(50,20)) sapfluxnetr:::.accumulated_posix_aware(c(Sys.time(), Sys.time() -1))
Run the code above in your browser using DataLab