powered by
generates a call to list to capture the fixed metrics in a quosure lambda style
.fixed_metrics_funs(probs, centroid)
probs vector for quantile
logical indicating if centroid calculation must be made. (i.e. in monthly metrics, the centroid calculation is not needed)
Calculated metrics are as follow:
mean: Mean value for the selected period
sd: Standard deviation for the selected period
coverage: Percentage of coverage as the percentage of no NAs in the expected length of the period, stated by the site timestep
q*: q95 by default. Quantile value for the selected period. Quantiles to calculate are stated in the probs argument
accumulated: Accumulated value on the selected period
centroid: daily centroid value in the selected period, calculated only if centroid argument is TRUE
sapfluxnetr:::.fixed_metrics_funs(0.95, FALSE) sapfluxnetr:::.fixed_metrics_funs(c(0.05, 0.95), TRUE)
Run the code above in your browser using DataLab