Learn R Programming

sapfluxnetr (version 0.1.5)

.flag: helper function to flag the mutated data in sfn_mutate and sfn_mutate_at

Description

This function will add the "USER_MODF" flag to the data point flags

Usage

.flag(x)

Value

A vector of the same length than x with the variable flags modified

Arguments

x

variable to flag

Examples

Run this code
sapfluxnetr:::.flag('')
sapfluxnetr:::.flag('OUT_WARNING')

Run the code above in your browser using DataLab