Learn R Programming

sapfluxnetr (version 0.1.5)

.parse_period: .parse_period

Description

Util to parse the period supplied to the function call to create the collapsed timestamp

Usage

.parse_period(period)

Value

a list, with the freq value as numeric and the period value as character

Arguments

period

Period in the "number period" format

Examples

Run this code
sapfluxnetr:::.parse_period('1 day')

Run the code above in your browser using DataLab