Learn R Programming

sapfluxnetr (version 0.1.5)

.timezone_dic: Timezones dictionary

Description

Transforms timezone ISO code to character vector compatible with lubridate and POSIXct

Usage

.timezone_dic(tz)

Value

A character vector with the timezone code compatible with lubridate and as.POSIXct

Arguments

tz

Character vector with the ISO code of the timezone as provided in env_time_zone variable in environmental_md

Details

GMT time zones are used, as they are day saving light time (DST) agnostic, and in that way the DST can setted if the metadata says so. GMT are sign exchanged to be compatible with ISO.