Learn R Programming

sapfluxnetr (version 0.1.5)

ARG_MAZ: ARG_MAZ sapfluxnet site

Description

Example site for package usage demonstration based on ARG_MAZ

Usage

ARG_MAZ

Arguments

Format

An sfn_data class object with the data and metadata for ARG_MAZ site

Examples

Run this code
data('ARG_MAZ', package = 'sapfluxnetr')
ARG_MAZ

Run the code above in your browser using DataLab