Learn R Programming

sapfluxnetr (version 0.1.5)

ARG_TRE: ARG_TRE sapfluxnet site

Description

Example site for package usage demonstration based on ARG_TRE

Usage

ARG_TRE

Arguments

Format

An sfn_data class object with the data and metadata for ARG_TRE site

Examples

Run this code
data('ARG_TRE', package = 'sapfluxnetr')
ARG_TRE

Run the code above in your browser using DataLab