Learn R Programming

sapfluxnetr (version 0.1.5)

describe_md_variable: Detailed description of metadata variables

Description

describe_md_variable prints in console a detailed description for the requested variable. Useful to know which values to filter or in which units the variables are.

Usage

describe_md_variable(variable)

Value

Nothing, prints information to console

Arguments

variable

A character with the name of the variable

Examples

Run this code
# info about the method used to measure sapflow (pl_sens_meth)
describe_md_variable('pl_sens_meth')

Run the code above in your browser using DataLab