Learn R Programming

sapfluxnetr (version 0.1.5)

sfn_data_validity: Validity method for sfn_data class

Description

Validation checks for generating sfn_data class objects

Arguments

Details

This method is used internally when creating and/or modifying sfn_data class objects to ensure that the object returned is correct in terms of content classes and dimensions (i.e. sapflow data and environmental data has the same length)