Generics for getting the info in the slots of SfnData
get_sapf_data(object, ...)get_env_data(object, ...)
get_sapf_flags(object, ...)
get_env_flags(object, ...)
get_timestamp(object, ...)
get_solar_timestamp(object, ...)
get_si_code(object, ...)
get_site_md(object, ...)
get_stand_md(object, ...)
get_species_md(object, ...)
get_plant_md(object, ...)
get_env_md(object, ...)
Object to get data from
Further arguments to pass to the corresponding get method
see sfn_get_methods for detailed info about using the get
methods in sfn_data class objects and
sfn_multi_get_methods for detailed info about using the get
methods in sfn_data_multi class objects.