powered by
Util to parse the period supplied to the function call to create the collapsed timestamp
.parse_period(period)
a list, with the freq value as numeric and the period value as character
Period in the "number period" format
sapfluxnetr:::.parse_period('1 day')
Run the code above in your browser using DataLab