powered by
Example site for package usage demonstration based on ARG_MAZ
ARG_MAZ
An sfn_data class object with the data and metadata for ARG_MAZ site
data('ARG_MAZ', package = 'sapfluxnetr') ARG_MAZ
Run the code above in your browser using DataLab