powered by
describe_md_variable prints in console a detailed description for the requested variable. Useful to know which values to filter or in which units the variables are.
describe_md_variable
describe_md_variable(variable)
Nothing, prints information to console
A character with the name of the variable
# info about the method used to measure sapflow (pl_sens_meth) describe_md_variable('pl_sens_meth')
Run the code above in your browser using DataLab