Calculate the normalized diurnal centroid for sapflow variables
norm_diurnal_centroid(sapf_var, rad_var)A numeric value with the normalized diurnal centroid value
A numeric vector containing the sapflow values for a day at a regular intervals. Missing values are allowed but not recommended.
A numeric vector containing the incoming radiation for a day at a regular intervals. Missing values are allowed but not recommended. Must be the same length as sapf_var.
This function calculates the diurnal centroid of sapflow measures relative to the diurnal centroid of incoming radiation (in any units). For that the incoming radiation diurnal centroid is substracted from the sapflow diurnal centroid:
$$ Sapf_cent - IncomingRad_cent $$
Jacob Nelson & Víctor Granda
The code for this function has been kindly provided by Jacob Nelson in python
(see https://github.com/jnelson18/FluxnetTools/blob/master/FileS3.py) and has
been translated to a tidy data philosophy in R to be used inside a
summarise statement.