sfn_data_multi_validity: Validity method for sfn_data_multi class
Description
Validation checks for generating sfn_data_multi class objects
Arguments
Details
This method is used internally to ensure the correctness of the sfn_data_multi
object. Basically ensures that the object returned is a list of sfn_data
class objects